==> jc-1.4.0.tar.gz: java/awt/BufferCapabilities__24FlipContents.h <==
// public final class java.awt.BufferCapabilities$FlipContents

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 294b49cfb5ac9e2c java_awt_BufferCapabilities__24FlipContents
// @dep_class 2a7152deee1944f1 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_BufferCapabilities__24FlipContents_H_
#define _JC_java_awt_BufferCapabilities__24FlipContents_H_

// Forward structure declarations
struct _jc_java_awt_BufferCapabilities__24FlipContents$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_BufferCapabilities__24FlipContents$sub_refs	_jc_java_awt_BufferCapabilities__24FlipContents$sub_refs;
typedef struct _jc_java_awt_BufferCapabilities__24FlipContents$sub_nonrefs	_jc_java_awt_BufferCapabilities__24FlipContents$sub_nonrefs;
typedef struct _jc_java_awt_BufferCapabilities__24FlipContents$refs	_jc_java_awt_BufferCapabilities__24FlipContents$refs;
typedef struct _jc_java_awt_BufferCapabilities__24FlipContents$nonrefs	_jc_java_awt_BufferCapabilities__24FlipContents$nonrefs;
typedef struct _jc_java_awt_BufferCapabilities__24FlipContents$object	_jc_java_awt_BufferCapabilities__24FlipContents$object;

typedef struct _jc_java_awt_BufferCapabilities__24FlipContents$fields_struct	_jc_java_awt_BufferCapabilities__24FlipContents$fields_struct;
typedef const struct _jc_java_awt_BufferCapabilities__24FlipContents$vmethods	_jc_java_awt_BufferCapabilities__24FlipContents$vmethods;
typedef const struct _jc_java_awt_BufferCapabilities__24FlipContents$vtable	_jc_java_awt_BufferCapabilities__24FlipContents$vtable;
typedef const struct _jc_java_awt_BufferCapabilities__24FlipContents$vtype	_jc_java_awt_BufferCapabilities__24FlipContents$vtype;

// Class fields structure
struct _jc_java_awt_BufferCapabilities__24FlipContents$fields_struct {
	struct _jc_java_awt_BufferCapabilities__24FlipContents$object	*BACKGROUND;
	struct _jc_java_awt_BufferCapabilities__24FlipContents$object	*COPIED;
	_jc_object_array	*NAMES;
	struct _jc_java_awt_BufferCapabilities__24FlipContents$object	*PRIOR;
	struct _jc_java_awt_BufferCapabilities__24FlipContents$object	*UNDEFINED;
};
extern _jc_java_awt_BufferCapabilities__24FlipContents$fields_struct _jc_java_awt_BufferCapabilities__24FlipContents$class_fields;

// Constructors
extern void _jc_java_awt_BufferCapabilities__24FlipContents$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_BufferCapabilities__24FlipContents$object *, jint);

// Static methods
extern void _jc_java_awt_BufferCapabilities__24FlipContents$method$_clinit$a816641e0ba8bfef(_jc_env *);

// Virtual methods structure
struct _jc_java_awt_BufferCapabilities__24FlipContents$vmethods {
};

// Vtable
struct _jc_java_awt_BufferCapabilities__24FlipContents$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_BufferCapabilities__24FlipContents$vmethods	java_awt_BufferCapabilities__24FlipContents;
};

// Vtype
struct _jc_java_awt_BufferCapabilities__24FlipContents$vtype {
	_jc_type			type;
	_jc_java_awt_BufferCapabilities__24FlipContents$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_BufferCapabilities__24FlipContents$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_BufferCapabilities__24FlipContents$refs {
    _jc_java_awt_BufferCapabilities__24FlipContents$sub_refs	java_awt_BufferCapabilities__24FlipContents;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_BufferCapabilities__24FlipContents$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_BufferCapabilities__24FlipContents$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_BufferCapabilities__24FlipContents$sub_nonrefs	java_awt_BufferCapabilities__24FlipContents;
};

// Object instance structure
struct _jc_java_awt_BufferCapabilities__24FlipContents$object {
	_jc_java_awt_BufferCapabilities__24FlipContents$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_BufferCapabilities__24FlipContents$vtype	*vtype;
	_jc_java_awt_BufferCapabilities__24FlipContents$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_BufferCapabilities__24FlipContents$vtype _jc_java_awt_BufferCapabilities__24FlipContents$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_BufferCapabilities__24FlipContents, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_BufferCapabilities__24FlipContents$class_object;

#endif	/* _JC_java_awt_BufferCapabilities__24FlipContents_H_ */

==> jc-1.4.5.tar.gz: java/awt/BufferCapabilities__24FlipContents.h <==
// public final class java.awt.BufferCapabilities$FlipContents

// class file dependencies
// @dep_class ad57b0121b5be9ed java_awt_AttributeValue
// @dep_class 294b49cfb5ac9e2c java_awt_BufferCapabilities__24FlipContents
// @dep_class 1c4f1fc002fc96e5 java_lang_Object

// header file dependencies
// @dep_header java_awt_AttributeValue

#include "java/awt/AttributeValue.h"

#ifndef _JC_java_awt_BufferCapabilities__24FlipContents_H_
#define _JC_java_awt_BufferCapabilities__24FlipContents_H_

// Forward structure declarations
struct _jc_java_awt_BufferCapabilities__24FlipContents$object;
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_awt_BufferCapabilities__24FlipContents$sub_refs	_jc_java_awt_BufferCapabilities__24FlipContents$sub_refs;
typedef struct _jc_java_awt_BufferCapabilities__24FlipContents$sub_nonrefs	_jc_java_awt_BufferCapabilities__24FlipContents$sub_nonrefs;
typedef struct _jc_java_awt_BufferCapabilities__24FlipContents$refs	_jc_java_awt_BufferCapabilities__24FlipContents$refs;
typedef struct _jc_java_awt_BufferCapabilities__24FlipContents$nonrefs	_jc_java_awt_BufferCapabilities__24FlipContents$nonrefs;
typedef struct _jc_java_awt_BufferCapabilities__24FlipContents$object	_jc_java_awt_BufferCapabilities__24FlipContents$object;

typedef struct _jc_java_awt_BufferCapabilities__24FlipContents$fields_struct	_jc_java_awt_BufferCapabilities__24FlipContents$fields_struct;
typedef const struct _jc_java_awt_BufferCapabilities__24FlipContents$vmethods	_jc_java_awt_BufferCapabilities__24FlipContents$vmethods;
typedef const struct _jc_java_awt_BufferCapabilities__24FlipContents$vtable	_jc_java_awt_BufferCapabilities__24FlipContents$vtable;
typedef const struct _jc_java_awt_BufferCapabilities__24FlipContents$vtype	_jc_java_awt_BufferCapabilities__24FlipContents$vtype;

// Class fields structure
struct _jc_java_awt_BufferCapabilities__24FlipContents$fields_struct {
	struct _jc_java_awt_BufferCapabilities__24FlipContents$object	*BACKGROUND;
	struct _jc_java_awt_BufferCapabilities__24FlipContents$object	*COPIED;
	_jc_object_array	*NAMES;
	struct _jc_java_awt_BufferCapabilities__24FlipContents$object	*PRIOR;
	struct _jc_java_awt_BufferCapabilities__24FlipContents$object	*UNDEFINED;
};
extern _jc_java_awt_BufferCapabilities__24FlipContents$fields_struct _jc_java_awt_BufferCapabilities__24FlipContents$class_fields;

// Constructors
extern void _jc_java_awt_BufferCapabilities__24FlipContents$method$_init$7f1776288300b98d(_jc_env *, struct _jc_java_awt_BufferCapabilities__24FlipContents$object *, jint) _JC_JCNI_ATTR;

// Static methods
extern void _jc_java_awt_BufferCapabilities__24FlipContents$method$_clinit$a816641e0ba8bfef(_jc_env *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_awt_BufferCapabilities__24FlipContents$vmethods {
};

// Vtable
struct _jc_java_awt_BufferCapabilities__24FlipContents$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_awt_AttributeValue$vmethods	java_awt_AttributeValue;
	_jc_java_awt_BufferCapabilities__24FlipContents$vmethods	java_awt_BufferCapabilities__24FlipContents;
};

// Vtype
struct _jc_java_awt_BufferCapabilities__24FlipContents$vtype {
	_jc_type			type;
	_jc_java_awt_BufferCapabilities__24FlipContents$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_awt_BufferCapabilities__24FlipContents$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_awt_BufferCapabilities__24FlipContents$refs {
    _jc_java_awt_BufferCapabilities__24FlipContents$sub_refs	java_awt_BufferCapabilities__24FlipContents;
    _jc_java_awt_AttributeValue$sub_refs	java_awt_AttributeValue;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_awt_BufferCapabilities__24FlipContents$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_awt_BufferCapabilities__24FlipContents$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_awt_AttributeValue$sub_nonrefs	java_awt_AttributeValue;
    _jc_java_awt_BufferCapabilities__24FlipContents$sub_nonrefs	java_awt_BufferCapabilities__24FlipContents;
};

// Object instance structure
struct _jc_java_awt_BufferCapabilities__24FlipContents$object {
	_jc_java_awt_BufferCapabilities__24FlipContents$refs	refs[0];
	_jc_word		lockword;
	_jc_java_awt_BufferCapabilities__24FlipContents$vtype	*vtype;
	_jc_java_awt_BufferCapabilities__24FlipContents$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_awt_BufferCapabilities__24FlipContents$vtype _jc_java_awt_BufferCapabilities__24FlipContents$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_awt_BufferCapabilities__24FlipContents, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_awt_BufferCapabilities__24FlipContents$class_object;

#endif	/* _JC_java_awt_BufferCapabilities__24FlipContents_H_ */
